@@ -49,7 +49,7 @@ def config_logger(session_id: str, identifier: str | None, output: Literal["cons
     logger.propagate = False
 
 
-async def run_executor(address: str, session_id: str, tmp_dir: str, package: str | None, session_dir: str, identifier: str | None = None):
+async def run_executor(address: str, session_id: str, tmp_dir: str, package: str | None, session_dir: str, identifier: str | None = None, debug_port: int | None = None):
 
     if identifier is not None:
         mainframe = Mainframe(address, f"python-executor-id-{identifier}", logger)
@@ -72,6 +72,8 @@ async def run_executor(address: str, session_id: str, tmp_dir: str, package: str
     elif os.path.exists("/app/workspace"):
         sys.path.append("/app/workspace")
 
+    package_name = os.path.basename(package) if package is not None else "workspace"
+
 
     def not_current_session(message):
         return message.get("session_id") != session_id
@@ -144,7 +146,7 @@ async def run_executor(address: str, session_id: str, tmp_dir: str, package: str
     mainframe.subscribe(exit_report_topic(), service_exit)
     mainframe.subscribe(status_report_topic(), service_status)
 
-    mainframe.notify_executor_ready(session_id, EXECUTOR_NAME, package, identifier)
+    mainframe.notify_executor_ready(session_id, package, identifier, debug_port)
 
     async def spawn_service(message: ServiceExecutePayload, service_hash: str):
         logger.info(f"create new service {message.get('dir')}")
@@ -211,12 +213,12 @@ async def run_executor(address: str, session_id: str, tmp_dir: str, package: str
             else:
                 if not_current_session(message):
                     continue
-                run_block_in_new_thread(message, mainframe, session_dir=session_dir, tmp_dir=tmp_dir)
+                run_block_in_new_thread(message, mainframe, session_dir=session_dir, tmp_dir=tmp_dir, package_name=package_name)
 
-def run_block_in_new_thread(message, mainframe: Mainframe, session_dir: str, tmp_dir: str):
+def run_block_in_new_thread(message, mainframe: Mainframe, session_dir: str, tmp_dir: str, package_name: str):
 
     async def run():
-        await run_block(message, mainframe, session_dir=session_dir, tmp_dir=tmp_dir)
+        await run_block(message, mainframe, session_dir=session_dir, tmp_dir=tmp_dir, package_name=package_name)
     run_in_new_thread(run)
 
 def main():
@@ -234,38 +236,47 @@ def main():
     parser.add_argument("--wait-for-client", help="wait for client to connect", default=False, action="store_true")
 
     try:
-        args = parser.parse_args()
+        namespace, unknown_args = parser.parse_known_args()
     except Exception as e:
-        print(f"parse args error: {e}")
+        hook.original_print(f"parse args error: {e}")
         # because we hook sys.exit in hook.py and raise a exception, the exit will be reset to 1.
         # parser origin exit code is 2. so we use 2 here.
-        sys.exit(2)
+        hook.original_exit(2)
 
-    address: str = args.address
-    session_id: str = str(args.session_id)
-    output: Literal["console", "file"] = args.output
-    package: str | None = args.package
-    session_dir: str = args.session_dir
-    tmp_dir: str = args.tmp_dir
-    identifier: str | None = args.identifier
+    address: str = namespace.address
+    session_id: str = str(namespace.session_id)
+    output: Literal["console", "file"] = namespace.output
+    package: str | None = namespace.package
+    session_dir: str = namespace.session_dir
+    tmp_dir: str = namespace.tmp_dir
+    identifier: str | None = namespace.identifier
 
     config_logger(session_id, identifier, output)
 
-    if args.debug_port is not None and args.debug_port.isdigit():
+    if len(unknown_args) > 0:
+        logger.warning(f"receive unknown args: {unknown_args}")
+
+    debug_port = None
+    if namespace.debug_port is not None and namespace.debug_port.isdigit():
         try:
             import debugpy
-            debugpy.listen(int(args.debug_port))
-            logger.info(f"debugpy listen on port {args.debug_port}")
-            if args.wait_for_client:
+            debugpy.listen(int(namespace.debug_port))
+            logger.info(f"debugpy listen on port {namespace.debug_port}")
+            if namespace.wait_for_client:
                 logger.info("wait for client to connect")
                 debugpy.wait_for_client()
                 logger.info("client connected")
+            debug_port = int(namespace.debug_port)
         except ImportError:
             logger.warning("Warning: debugpy not installed, debugging functionality will not be available")
+            debug_port = None
         except Exception as e:
             logger.warning(f"Warning: debugpy listen failed: {e}")
+            debug_port = None
+    else:
+        debug_port = None
 
-    run_async_code(run_executor(address=address, tmp_dir=tmp_dir, session_id=session_id, package=package, session_dir=session_dir, identifier=identifier))
+    run_async_code(run_executor(address=address, tmp_dir=tmp_dir, session_id=session_id, package=package, session_dir=session_dir, identifier=identifier, debug_port=debug_port))
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
